@@ -4,9 +4,11 @@ use strict;
 use Getopt::Long;
 use CGI::Wiki::Setup::SQLite;
 
-my ($dbname, $help);
-GetOptions("name=s" => \$dbname,
-           "help"   => \$help);
+my ($dbname, $help, $preclear);
+GetOptions( "name=s"         => \$dbname,
+            "help"           => \$help,
+            "force-preclear" => \$preclear
+           );
 
 unless (defined($dbname)) {
     print "You must supply a database name with the --name option\n";
@@ -19,6 +21,10 @@ if ($help) {
     exit 0;
 }
 
+if ($preclear) {
+    CGI::Wiki::Setup::SQLite::cleardb($dbname);
+}
+
 CGI::Wiki::Setup::SQLite::setup($dbname);
 
 =head1 NAME
@@ -27,11 +33,20 @@ user-setup-sqlite - set up a SQLite storage backend for CGI::Wiki
 
 =head1 SYNOPSIS
 
+# Set up or update the storage backend, leaving any existing data intact.
+# Useful for upgrading from old versions of CGI::Wiki to newer ones with
+# more backend features.
+
   user-setup-sqlite --name mywiki
 
+# Clear out any existing data and set up a fresh backend from scratch.
+
+  user-setup-sqlite --name mywiki \
+                    --force-preclear
+
 =head1 DESCRIPTION
 
-Takes one argument:
+Takes one mandatory argument:
 
 =over 4
 
@@ -40,6 +55,19 @@ Takes one argument:
 The name of the file to store the SQLite database in.  It will be
 created if it doesn't already exist.
 
+=back
+
+and one optional flag:
+
+=over 4
+
+=item force-preclear
+
+By default, this script will leave any existing data alone.  To force
+that to be cleared out first, pass the C<--force-preclear> flag.
+
+=back
+
 =head1 AUTHOR
 
 Kake Pugh (kake@earth.li).
